@@ -20,7 +20,9 @@ x <- seq(-2.0, 0.6, length.out=240)
 y <- seq(-1.3, 1.3, length.out=240)
 m <- 100
 
-library(nws); s <- sleigh()
+if (! suppressWarnings(require(nwsPro, quietly=TRUE)))
+  library(nws)
+s <- sleigh()
 opts <- list(chunkSize=10, loadFactor=4)
 z <- eachElem(s, vmandelbrot, list(b0=y), list(av=x, lim=m), eo=opts)
 z <- do.call(cbind, z)
