@@ -1,4 +1,5 @@
-library(nwsPro)
+if (! suppressWarnings(require(nwsPro, quietly=TRUE)))
+  library(nws)
 library(grid)
 options(device='X11')
 grid.newpage()
